@@ -85,18 +85,26 @@
 database_type='Psycopg'
 __doc__='''%s Database Connection
 
-$Id: DA.py,v 1.15.2.2 2002/03/27 15:40:26 fog Exp $''' % database_type
-__version__='$Revision: 1.15.2.2 $'[11:-2]
+$Id: DA.py,v 1.15.2.3 2002/06/17 23:45:00 fog Exp $''' % database_type
+__version__='$Revision: 1.15.2.3 $'[11:-2]
 
 from db import DB
-import Shared.DC.ZRDB.Connection, sys, DABase
+import Shared.DC.ZRDB.Connection, sys, DABase, time
 from Globals import HTMLFile
 from ImageFile import ImageFile
 from ExtensionClass import Base
 from string import find,join,split
-from DateTime import DateTime
-import time
-from psycopg import new_type, register_type, DATETIME, TIME, DATE, INTERVAL
+try:
+    import psycopg
+    from psycopg import new_type, register_type, DATETIME, TIME, DATE, INTERVAL
+    print "psycopg version is", psycopg.__version__
+except StandardError, err:
+    print err
+try:
+    from DateTime import DateTime
+    print "datetime object:", repr(DateTime)
+except StandardError, err:
+    print err
 
 try:
     from App.Dialogs import MessageDialog
@@ -130,7 +138,7 @@ def cast_Date(str):
 def cast_Time(str):
     return DateTime(time.strftime('%Y-%m-%d %H:%M:%S',
                                   time.localtime(time.time())[:3]+
-                                  time.strptime(str, "%H:%M:%S")[3:]))
+                                  time.strptime(str[:8], "%H:%M:%S")[3:]))
 
 # Convert a time string from postgres to a DateTime(zope version) object.
 # WARNING: We set the day as the epoch day (1970-01-01) since this
