@@ -84,8 +84,8 @@
 ##############################################################################
 __doc__='''Database Connection
 
-$Id: DABase.py,v 1.9 2001/10/29 17:57:58 fog Exp $'''
-__version__='$Revision: 1.9 $'[11:-2]
+$Id: DABase.py,v 1.9.2.1 2002/02/12 18:39:41 fog Exp $'''
+__version__='$Revision: 1.9.2.1 $'[11:-2]
 
 
 import Shared.DC.ZRDB.Connection, sys
@@ -111,11 +111,6 @@ class Connection(Shared.DC.ZRDB.Connection.Connection):
 
     info=None
 
-    def __init__(self, id, title, connection_string, zdatetime, check=None):
-        self.zdatetime=zdatetime
-        self.id=str(id)
-        self.edit(title, connection_string, zdatetime, check)
-
     def tpValues(self):
         #if hasattr(self, '_v_tpValues'): return self._v_tpValues
         r=[]
@@ -149,27 +144,6 @@ class Connection(Shared.DC.ZRDB.Connection.Connection):
             return self._v_tables.__of__(self)
         raise KeyError, name
 
-    def edit(self, title, connection_string, zdatetime, check=1):
-        self.title=title
-        self.connection_string=connection_string
-        self.zdatetime=zdatetime
-        self.set_type_casts()
-        if check: self.connect(connection_string)
-
-    manage_properties=HTMLFile('connectionEdit', globals())
-    def manage_edit(self, title, connection_string,
-                    zdatetime=None, check=None, REQUEST=None):
-        """Change connection
-        """
-        self.edit(title, connection_string, zdatetime, check=None)
-        if REQUEST is not None:
-            return MessageDialog(
-                title='Edited',
-                message='<strong>%s</strong> has been edited.' % self.id,
-                action ='./manage_main',
-                )
-
-
     def manage_wizard(self, tables):
         " "
 
@@ -184,6 +158,7 @@ class Connection(Shared.DC.ZRDB.Connection.Connection):
 
 class TableBrowserCollection(Acquisition.Implicit):
     "Helper class for accessing tables via URLs"
+    pass
 
 class Browser(Base):
     def __getattr__(self, name):
@@ -196,7 +171,8 @@ class values:
 
     def __getitem__(self, i):
         try: return self._d[i]
-        except AttributeError: pass
+        except AttributeError:
+            pass
         self._d=self._f()
         return self._d[i]
 
@@ -262,9 +238,6 @@ class TableBrowser(Browser, Acquisition.Implicit):
                     raise ValueError, (
                         'no default was given for <em>%s</em>' % n)
 
-            
-            
-
 class ColumnBrowser(Browser):
     icon='field'
 
