@@ -83,8 +83,8 @@
 # 
 ##############################################################################
 
-'''$Id: db.py,v 1.29.2.4 2002/03/27 15:40:26 fog Exp $'''
-__version__='$Revision: 1.29.2.4 $'[11:-2]
+'''$Id: db.py,v 1.29.2.5 2002/06/17 23:45:00 fog Exp $'''
+__version__='$Revision: 1.29.2.5 $'[11:-2]
 
 
 from Shared.DC.ZRDB.TM import TM
@@ -116,11 +116,20 @@ class DB(TM,dbi_db.DB):
         self.db = self.connect(self.connection)
     
     def _finish(self, *ignored):
-        if self.db: self.db.commit()
+	try:
+            if hasattr(self, 'db') and self.db:
+                self.db.commit()
+            else:
+                self.db = self.connect(self.connection)
+        except psycopg.Error:
+            pass
             
     def _abort(self, *ignored):
         try:
-            self.db.rollback()
+            if hasattr(self, 'db') and self.db:
+                self.db.rollback()
+            else:
+                self.db = self.connect(self.connection)
         except psycopg.Error:
             pass
 
@@ -214,7 +223,7 @@ class DB(TM,dbi_db.DB):
             failures = 0
             return self.query(query_string, max_rows)
         except psycopg.InterfaceError, err:
-            if self.db is not None:
+            if hasattr(self, 'db'):
                 del c ; del self.db
                 self.db = self.connect(self.connection)
                 return self.query(query_string, max_rows)
