@@ -38,8 +38,9 @@ basic_types = (['NUMBER', ['INT8', 'INT4', 'INT2', 'FLOAT8', 'FLOAT4',
                ['STRING', ['NAME', 'CHAR', 'TEXT', 'BPCHAR',
                            'VARCHAR', 'LZTEXT']],
                ['BOOLEAN', ['BOOL']],
-               ['DATETIME', ['DATE', 'TIME', 'TIMETZ', 'TIMESTAMP', 'TINTERVAL',
-                            'INTERVAL']],
+               ['DATETIME', ['DATE', 'TIME', 'TIMETZ', 
+                             'TIMESTAMP', 'TIMESTAMPTZ', 
+                             'TINTERVAL', 'INTERVAL']],
                ['TIME', ['TIME', 'TIMETZ']],
                ['DATE', ['DATE', 'TIMESTAMP']],
                ['INTERVAL', ['TINTERVAL', 'INTERVAL']],
