@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001 Michele Comitini <mcm@initd.net>
- * Copyright (C) 2001 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2001-2002 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of the psycopg module.
  *
@@ -21,7 +21,7 @@
 
 /*
  * cursor.c - defines the cursor object DBAPI 2.0
- * $Id: cursor.c,v 1.102.2.6 2002/04/21 22:58:52 fog Exp $
+ * $Id: cursor.c,v 1.102.2.7 2002/06/17 23:45:00 fog Exp $
  */
 
 #include <assert.h>
@@ -1206,24 +1206,27 @@ psyco_curs_fetchone(cursobject *self, PyObject *args)
 
     r = self->pgres;
     for (i = 0; i < coln; i++) {
-        PyObject *val;
+        PyObject *val, *str;
+        PyObject *arg = PyTuple_New(1);
+        
         if (PQgetisnull(r, self->row, i)) {
             Py_INCREF(Py_None);
-            val = Py_None;
+            str = Py_None;
+            Dprintf("psyco_curs_fetchone: row %ld, element %d is None\n",
+                    self->row, i);
         }
         else {
             char *s = PQgetvalue(r, self->row, i);
             int l = PQgetlength(r, self->row, i);
-            PyObject *str = PyString_FromStringAndSize(s, l);
-            PyObject *arg = PyTuple_New(1);
-
+            str = PyString_FromStringAndSize(s, l);
             Dprintf("psyco_curs_fetchone: row %ld, element %d, len %i\n",
                     self->row, i, l);
-            PyTuple_SET_ITEM(arg, 0, str);
-            val = PyObject_CallObject(PyTuple_GET_ITEM(self->casts, i), arg);
-            
-            Py_DECREF(arg);
         }
+        
+        PyTuple_SET_ITEM(arg, 0, str);
+        val = PyObject_CallObject(PyTuple_GET_ITEM(self->casts, i), arg);    
+        Py_DECREF(arg);
+        
         if (val) {
             PyTuple_SET_ITEM(res, i, val);
         }
