@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001,2002 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2001-2002 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of the psycopg module.
  *
@@ -20,7 +20,7 @@
 
 /*
  * typeobj.c -- define the type objects
- * $Id: typeobj.c,v 1.20.2.9 2002/04/21 22:58:52 fog Exp $
+ * $Id: typeobj.c,v 1.20.2.10 2002/06/17 23:45:00 fog Exp $
  */
 
 #include "assert.h"
@@ -34,6 +34,7 @@ static PyObject *
 psyco_INTEGER_cast(PyObject *s)
 {
     PyObject *i;
+    if (s == Py_None) return s;
     i = PyNumber_Int(s);
     Dprintf("psyco_STRING_cast(): i->refcnt = %d\n", i->ob_refcnt);
     return i;
@@ -42,18 +43,21 @@ psyco_INTEGER_cast(PyObject *s)
 static PyObject *
 psyco_LONGINTEGER_cast(PyObject *s)
 {
+    if (s == Py_None) return s;
     return PyNumber_Long(s);
 }
 
 static PyObject *
 psyco_FLOAT_cast(PyObject *s)
 {
+    if (s == Py_None) return s;
     return PyNumber_Float(s);
 }
 
 static PyObject *
 psyco_STRING_cast(PyObject *s)
 {
+    if (s == Py_None) return s;
     Py_INCREF(s);
     return s;
 }
@@ -64,9 +68,11 @@ psyco_DATE_cast(PyObject *s)
     int n, y=0, m=0, d=0;
     int hh=0, mm=0;
     double ss=0.0;
-
+    
     char *str = PyString_AsString(s);
 
+    if (s == Py_None) return s;
+    
     /* check for infinity */
     if (!strcmp(str, "infinity") || !strcmp(str, "-infinity")) {
         if (str[0] == '-') {
@@ -131,6 +137,8 @@ psyco_TIME_cast(PyObject *s)
     double ss=0.0;
     
     char *str = PyString_AsString(s);
+
+    if (s == Py_None) return s;
     
     /* postgres gives us only the time but a DateTime object wants a date too,
        so we use the unix epoch as the current date. */
@@ -166,6 +174,8 @@ psyco_INTERVAL_cast(PyObject *s)
     int part = 0;
     char *str;
 
+    if (s == Py_None) return s;
+    
     str = PyString_AsString(s);
     Dprintf("psyco_INTERVAL_cast(): s = %s\n", str);
     
@@ -275,6 +285,7 @@ psyco_INTERVAL_cast(PyObject *s)
 static PyObject *
 psyco_BOOLEAN_cast(PyObject *s)
 {
+    if (s == Py_None) return s;
     if (PyString_AsString(s)[0] == 't') return PyInt_FromLong(1L);
     else return PyInt_FromLong(0L);
 }
@@ -286,6 +297,8 @@ psyco_BINARY_cast(PyObject *s)
     char *str, *dstptr, *dststr;
     int len, i;
     PyObject *retstr;
+
+    if (s == Py_None) return s;
    
     str = PyString_AS_STRING(s);
     len = strlen(str);
@@ -544,7 +557,7 @@ psyco_DBAPITypeObject_call(PyObject *self, PyObject *args, PyObject *keywds)
     
     Dprintf("psyco_DBAPITypeObject_call: self = %p, args = %p\n", self, args);
     
-    if (!PyArg_ParseTuple(args, "O!", &PyString_Type, &string)) {
+    if (!PyArg_ParseTuple(args, "O", &string)) {
         return NULL;
     }
     
